@@ -1,5 +1,6 @@
 #  Copyright (c) 1999 John Aycock
 #  Copyright (c) 2000-2002 by hartmut Goebel <hartmut@goebel.noris.de>
+#  Copyright (c) 2005 by Dan Pascu <dan@windowmaker.org>
 #
 #  See main module for license.
 #
@@ -172,6 +173,7 @@ TABLE_DIRECT = {
 #   'dup_topx':		( '%c', 0),
     'designList':	( '%c = %c', 0, -1 ),
     'and':          	( '(%c and %c)', 0, 3 ),
+    'and2':          	( '%c', 4 ),
     'or':           	( '(%c or %c)', 0, 3 ),
     'compare':		( '(%c %[-1]{pattr} %c)', 0, 1 ),
     'cmp_list':		( '%c %c', 0, 1),
@@ -216,7 +218,9 @@ TABLE_DIRECT = {
     'elifelsestmt':	( '%|elif %c:\n%+%c%-%|else:\n%+%c%-', 0, 2, -2 ),
 
     'whilestmt':	( '%|while %c:\n%+%c%-\n', 1, 4 ),
-    'whileelsestmt':	( '%|while %c:\n%+%c%-%|else:\n%+%c%-\n', 1, 4, 9 ),
+    'while1stmt':	( '%|while 1:\n%+%c%-\n', 5 ),
+    'whileelsestmt':	( '%|while %c:\n%+%c%-%|else:\n%+%c%-\n', 1, 4, -2 ),
+    'while1elsestmt':	( '%|while 1:\n%+%c%-%|else:\n%+%c%-\n', 5, -2 ),
     'forstmt':		( '%|for %c in %c:\n%+%c%-\n', 3, 1, 4 ),
     'forelsestmt':	(
         '%|for %c in %c:\n%+%c%-%|else:\n%+%c%-\n', 3, 1, 4, -2
